@@ -4,6 +4,12 @@ def findFirst(target, goal):
             return i
     return -1
 
+def findFirstLambda(judgement, goal):
+    for i, j in enumerate(goal):
+        if judgement(j):
+            return i
+    return -1
+
 def findAll(target, goal):
     res = []
     for i, j in enumerate(goal):
@@ -11,6 +17,13 @@ def findAll(target, goal):
             res.append(i)
     return res
 
+def findAllLambda(judgement, goal):
+    res = []
+    for i, j in enumerate(goal):
+        if judgement(j):
+            res.append(i)
+    return res
+
 def binarySearch(target, goal):
     left, right = 0, len(goal) - 1
     if target >= goal[-1]:
